summaryrefslogtreecommitdiff
path: root/drivers/net/mcffec.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/net/mcffec.c')
-rw-r--r--drivers/net/mcffec.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/drivers/net/mcffec.c b/drivers/net/mcffec.c
index f94a2d8123..4fa71360cf 100644
--- a/drivers/net/mcffec.c
+++ b/drivers/net/mcffec.c
@@ -513,18 +513,18 @@ static const struct eth_ops mcffec_ops = {
};
/*
* Boot sequence, called just after mcffec_ofdata_to_platdata,
* as DM way, it replaces old mcffec_initialize.
*/
static int mcffec_probe(struct udevice *dev)
{
- struct eth_pdata *pdata = dev_get_platdata(dev);
+ struct eth_pdata *pdata = dev_get_plat(dev);
struct fec_info_s *info = dev->priv;
int node = dev_of_offset(dev);
int retval, fec_idx;
const u32 *val;
- info->index = dev->seq;
+ info->index = dev_seq(dev);
info->iobase = pdata->iobase;
info->phy_addr = -1;
@@ -584,9 +584,9 @@ static int mcffec_remove(struct udevice *dev)
/*
* Boot sequence, called 1st
*/
-static int mcffec_ofdata_to_platdata(struct udevice *dev)
+static int mcffec_of_to_plat(struct udevice *dev)
{
- struct eth_pdata *pdata = dev_get_platdata(dev);
+ struct eth_pdata *pdata = dev_get_plat(dev);
const u32 *val;
pdata->iobase = dev_read_addr(dev);
@@ -610,10 +610,10 @@ U_BOOT_DRIVER(mcffec) = {
.name = "mcffec",
.id = UCLASS_ETH,
.of_match = mcffec_ids,
- .ofdata_to_platdata = mcffec_ofdata_to_platdata,
+ .of_to_plat = mcffec_of_to_plat,
.probe = mcffec_probe,
.remove = mcffec_remove,
.ops = &mcffec_ops,
- .priv_auto_alloc_size = sizeof(struct fec_info_s),
- .platdata_auto_alloc_size = sizeof(struct eth_pdata),
+ .priv_auto = sizeof(struct fec_info_s),
+ .plat_auto = sizeof(struct eth_pdata),
};
@@ -513,18 +513,18 @@ static const struct eth_ops mcffec_ops = {
};
/*
- * Boot sequence, called just after mcffec_ofdata_to_platdata,
+ * Boot sequence, called just after mcffec_of_to_plat,
* as DM way, it replaces old mcffec_initialize.
*/